@@ -1680,6 +1680,7 @@ launcher_plugin_menu_popup (gpointer user_data)
 {
   LauncherPlugin *plugin = XFCE_LAUNCHER_PLUGIN (user_data);
   gint            x, y;
+  GdkEventButton *event = NULL;
 
   panel_return_val_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin), FALSE);
 
@@ -1693,12 +1694,21 @@ launcher_plugin_menu_popup (gpointer user_data)
   else
     gtk_widget_set_state_flags (GTK_WIDGET (plugin->button), GTK_STATE_FLAG_CHECKED, TRUE);
 
+  /* avoid warning when there is no current event */
+  if (gtk_get_current_event () == NULL)
+    {
+      event = g_slice_new0 (GdkEventButton);
+      event->type = GDK_BUTTON_PRESS;
+      event->window = gdk_get_default_root_window ();
+    }
+
   /* popup the menu */
   xfce_panel_plugin_popup_menu (XFCE_PANEL_PLUGIN (plugin), GTK_MENU (plugin->menu),
-                                plugin->button, NULL);
+                                plugin->button, (GdkEvent *) event);
 
-  /* fallback to manual positioning, this is used with
-   * drag motion over the arrow button */
+  /* fallback to manual positioning, this is used with drag motion over the arrow button
+   * from e.g. Thunar, not from the app menu, where showing the menu does not work for
+   * some other reason: see https://gitlab.xfce.org/xfce/xfce4-panel/-/issues/205 */
   if (!gtk_widget_get_visible (plugin->menu))
     {
       /* make sure the size is allocated */
@@ -1863,14 +1873,6 @@ launcher_plugin_button_update_action_menu (LauncherPlugin *plugin)
   panel_return_if_fail (XFCE_IS_LAUNCHER_PLUGIN (plugin));
   panel_return_if_fail (plugin->menu == NULL);
 
-  /* If there are >1 items in the launcher don't show the action menu */
-  if (LIST_HAS_TWO_OR_MORE_ENTRIES (plugin->items))
-    {
-      xfce_panel_plugin_menu_destroy (XFCE_PANEL_PLUGIN (plugin));
-      plugin->action_menu = NULL;
-      return;
-    }
-
   if (G_LIKELY (plugin->items != NULL))
     item = GARCON_MENU_ITEM (plugin->items->data);
 
@@ -2305,6 +2307,13 @@ launcher_plugin_arrow_drag_leave_timeout (gpointer user_data)
   if (G_UNLIKELY (plugin->menu == NULL))
     return FALSE;
 
+  /* leave if the menu is already hidden */
+  if (! gtk_widget_get_visible (plugin->menu))
+    {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (plugin->arrow), FALSE);
+      return FALSE;
+    }
+
   device = gdk_seat_get_pointer (gdk_display_get_default_seat (gtk_widget_get_display (menu)));
   if (device == NULL)
     return FALSE;
