@@ -137,7 +137,7 @@ tasklist_plugin_construct (XfcePanelPlugin *panel_plugin)
   const PanelProperty  properties[] =
   {
     { "show-labels", G_TYPE_BOOLEAN },
-    { "grouping", G_TYPE_UINT },
+    { "grouping", G_TYPE_BOOLEAN },
     { "include-all-workspaces", G_TYPE_BOOLEAN },
     { "include-all-monitors", G_TYPE_BOOLEAN },
     { "flat-buttons", G_TYPE_BOOLEAN },
@@ -227,7 +227,6 @@ tasklist_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
   GtkBuilder     *builder;
   GObject        *dialog;
   GObject        *object;
-  GtkTreeIter     iter;
 
   /* setup the dialog */
   PANEL_UTILS_LINK_4UI
@@ -274,11 +273,6 @@ tasklist_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
   gtk_widget_hide (GTK_WIDGET (object));
 #endif
 
-  /* TODO: remove this if always group is supported */
-  object = gtk_builder_get_object (builder, "grouping-model");
-  if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (object), &iter, NULL, 2))
-    gtk_list_store_remove (GTK_LIST_STORE (object), &iter);
-
   gtk_widget_show (GTK_WIDGET (dialog));
 }
 
